@@ -15,16 +15,16 @@ installed duecredit.
 
 Then use in your code as
 
-    from .due import due, Doi, BibTeX
+    from .due import due, Doi, BibTeX, Text
 
 See  https://github.com/duecredit/duecredit/blob/master/README.md for examples.
 
 Origin:     Originally a part of the duecredit
-Copyright:  2015-2016  DueCredit developers
+Copyright:  2015-2019  DueCredit developers
 License:    BSD-2
 """
 
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 
 
 class InactiveDueCreditCollector(object):
@@ -39,7 +39,8 @@ class InactiveDueCreditCollector(object):
             return func
         return nondecorating_decorator
 
-    cite = load = add = _donothing
+    active = False
+    activate = add = cite = dump = load = _donothing
 
     def __repr__(self):
         return self.__class__.__name__ + '()'
@@ -51,7 +52,7 @@ def _donothing_func(*args, **kwargs):
 
 
 try:
-    from duecredit import due, BibTeX, Doi, Url
+    from duecredit import due, BibTeX, Doi, Url, Text
     if 'due' in locals() and not hasattr(due, 'cite'):
         raise RuntimeError(
             "Imported due lacks .cite. DueCredit is now disabled")
@@ -62,7 +63,7 @@ except Exception as e:
             "Failed to import duecredit due to %s" % str(e))
     # Initiate due stub
     due = InactiveDueCreditCollector()
-    BibTeX = Doi = Url = _donothing_func
+    BibTeX = Doi = Url = Text = _donothing_func
 
 # Emacs mode definitions
 # Local Variables:
