@@ -267,90 +267,15 @@ def get_tempfile_kwargs(tkwargs={}, prefix="", wrapped=None):
 
     return tkwargs_
 
-
-@optional_args
-def with_tempfile(t, content=None, **tkwargs):
-    """Decorator function to provide a temporary file name and remove it at the end
-
-    Parameters
-    ----------
-    mkdir : bool, optional (default: False)
-        If True, temporary directory created using tempfile.mkdtemp()
-    content : str or bytes, optional
-        Content to be stored in the file created
-    `**tkwargs`:
-        All other arguments are passed into the call to tempfile.mk{,d}temp(),
-        and resultant temporary filename is passed as the first argument into
-        the function t.  If no 'prefix' argument is provided, it will be
-        constructed using module and function names ('.' replaced with
-        '_').
-
-    To change the used directory without providing keyword argument 'dir' set
-    DUECREDIT_TESTS_TEMPDIR.
-
-    Examples
-    --------
-
-        @with_tempfile
-        def test_write(tfile):
-            open(tfile, 'w').write('silly test')
-    """
-
-    @wraps(t)
-    def newfunc(*arg, **kw):
-
-        tkwargs_ = get_tempfile_kwargs(tkwargs, wrapped=t)
-
-        # if DUECREDIT_TESTS_TEMPDIR is set, use that as directory,
-        # let mktemp handle it otherwise. However, an explicitly provided
-        # dir=... will override this.
-        mkdir = tkwargs_.pop('mkdir', False)
-
-        filename = {False: tempfile.mktemp,
-                    True: tempfile.mkdtemp}[mkdir](**tkwargs_)
-        filename = realpath(filename)
-
-        if content:
-            with open(filename, 'w' + ('b' if isinstance(content, binary_type) else '')) as f:
-                f.write(content)
-        if __debug__:
-            lgr.debug('Running %s with temporary filename %s',
-                      t.__name__, filename)
-        try:
-            return t(*(arg + (filename,)), **kw)
-        finally:
-            # glob here for all files with the same name (-suffix)
-            # would be useful whenever we requested .img filename,
-            # and function creates .hdr as well
-            lsuffix = len(tkwargs_.get('suffix', ''))
-            filename_ = lsuffix and filename[:-lsuffix] or filename
-            filenames = glob.glob(filename_ + '*')
-            if len(filename_) < 3 or len(filenames) > 5:
-                # For paranoid yoh who stepped into this already ones ;-)
-                lgr.warning("It is unlikely that it was intended to remove all"
-                            " files matching %r. Skipping" % filename_)
-                return
-            for f in filenames:
-                try:
-                    rmtemp(f)
-                except OSError:
-                    pass
-
-    if tkwargs.get('mkdir', None) and content is not None:
-        raise ValueError("mkdir=True while providing content makes no sense")
-
-    return newfunc
-
-
 #
 # Context Managers
 #
 
-
 #
 # Additional handlers
 #
-_sys_excepthook = sys.excepthook # Just in case we ever need original one
+_sys_excepthook = sys.excepthook  # Just in case we ever need original one
+
 
 def setup_exceptionhook():
     """Overloads default sys.excepthook with our exceptionhook handler.
